<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Kepegawaian_model extends CI_Model
{
    public function __construct()
    {
        parent::__construct();
        $this->load->model('Kepegawaian_model');
    }

    public function count_employees()
    {
        return $this->db->count_all('karyawan');
    }
    
    public function count_employees_except_terminated_resigned()
    {
        $this->db->where_not_in('status', array('Diberhentikan', 'Resign'));
        return $this->db->get('karyawan')->num_rows();
    }

    public function count_employees_by_status($status)
    {
        $this->db->where('status', $status);
        return $this->db->count_all_results('karyawan');
    }

    public function get_pegawai_by_id($id_pegawai)
    {
        // Query database untuk mendapatkan data pegawai berdasarkan ID
        $query = $this->db->get_where('kepegawaian', array('id_pegawai' => $id_pegawai));

        // Mengembalikan hasil query dalam bentuk objek
        return $query->row();
    }

    public function tambah_riwayat_mutasi($karyawan, $divisi_awal, $divisi_baru, $sk, $tmt)
    {
        $data = array(
            'id_pegawai' => $karyawan,
            'jenis_perubahan' => '3',
            'tgl_sejarah' => date("Y-m-d"),
            'sk' => $sk,
            'tmt' => $tmt,
            'from' => $divisi_awal,
            'to' => $divisi_baru,
            'jam' => date("H:i:s"),
            'operator' => $this->session->userdata('id_pegawai')
        );

        $this->db->insert('sejarah_perubahan', $data);

        return true;
    }


    public function tambah_riwayat_promosi($karyawan, $divisi_awal, $divisi_baru, $sk, $tmt)
    {

        $data = array(
            'id_pegawai' => $karyawan,
            'jenis_perubahan' => '2',
            'tgl_sejarah' => date("Y-m-d"),
            'sk' => $sk,
            'tmt' => $tmt,
            'from' => $divisi_awal,
            'to' => $divisi_baru,
            'jam' => date("H:i:s"),
            'operator' => $this->session->userdata('id_pegawai')
        );

        $this->db->insert('sejarah_perubahan', $data);

        return true;
    }

    public function tambah_riwayat_sp1($karyawan, $sk, $tmt)
    {
        $pegawai = $this->Karyawan->detailKaryawan($karyawan);

        if (!$pegawai) {
            return false; // Tampilkan pesan kesalahan jika ID pegawai tidak valid
        }

        // Data untuk diinsert ke dalam tabel 'riwayat_promosi'
        $data = array(
            'id_pegawai' => $karyawan,
            'jenis_perubahan' => '4', // Mengambil nama operator dari session
            'tgl_sejarah' => date("Y-m-d"),
            'sk' => $sk, // Mengambil tanggal hari ini
            'tmt' => $tmt, // Status karyawan yang baru
            'from' => 'NULL',
            'to' => 'SP1',
            'jam' => date("H:i:s"),
            'operator' => $this->session->userdata('id_pegawai')
        );
        // Masukkan data mutasi ke dalam tabel "riwayat_mutasi" (ganti nama tabel)
        $this->db->insert('sejarah_perubahan', $data); // Ganti nama tabel
    }

    public function tambah_riwayat_sp2($karyawan, $sk, $tmt)
    {
        $pegawai = $this->Karyawan->detailKaryawan($karyawan);

        if (!$pegawai) {
            return false; // Tampilkan pesan kesalahan jika ID pegawai tidak valid
        }

        // Data untuk diinsert ke dalam tabel 'riwayat_promosi'
        $data = array(
            'id_pegawai' => $karyawan,
            'jenis_perubahan' => '5', // Mengambil nama operator dari session
            'tgl_sejarah' => date("Y-m-d"),
            'sk' => $sk, // Mengambil tanggal hari ini
            'tmt' => $tmt, // Status karyawan yang baru
            'from' => 'SP1',
            'to' => 'SP2',
            'jam' => date("H:i:s"),
            'operator' => $this->session->userdata('id_pegawai')
        );
        // Masukkan data mutasi ke dalam tabel "riwayat_mutasi" (ganti nama tabel)
        $this->db->insert('sejarah_perubahan', $data); // Ganti nama tabel
    }

    public function tambah_riwayat_dikeluarkan($karyawan, $sk, $tmt)
    {
        $pegawai = $this->Karyawan->detailKaryawan($karyawan);

        if (!$pegawai) {
            return false; // Tampilkan pesan kesalahan jika ID pegawai tidak valid
        }

        // Data untuk diinsert ke dalam tabel 'riwayat_promosi'
        $data = array(
            'id_pegawai' => $karyawan,
            'jenis_perubahan' => '6', // Mengambil nama operator dari session
            'tgl_sejarah' => date("Y-m-d"),
            'sk' => $sk, // Mengambil tanggal hari ini
            'tmt' => $tmt, // Status karyawan yang baru
            'from' => 'SP2',
            'to' => 'Diberhentikan',
            'jam' => date("H:i:s"),
            'operator' => $this->session->userdata('id_pegawai')
        );
        // Masukkan data mutasi ke dalam tabel "riwayat_mutasi" (ganti nama tabel)
        $this->db->insert('sejarah_perubahan', $data); // Ganti nama tabel
    }

    public function tambah_riwayat_pengangkatan($karyawan, $sk, $tmt, $status, $status_baru)
    {
        $pegawai = $this->Karyawan->detailKaryawan($karyawan);

        if (!$pegawai) {
            return false; // Tampilkan pesan kesalahan jika ID pegawai tidak valid
        }

        // Data untuk diinsert ke dalam tabel 'riwayat_promosi'
        $data = array(
            'id_pegawai' => $karyawan,
            'jenis_perubahan' => '1', // Mengambil nama operator dari session
            'tgl_sejarah' => date("Y-m-d"),
            'sk' => $sk, // Mengambil tanggal hari ini
            'tmt' => $tmt, // Status karyawan yang baru
            'jam' => date("H:i:s"),
            'from' => $status,
            'to' => $status_baru,
            'operator' => $this->session->userdata('id_pegawai')
        );
        // Masukkan data mutasi ke dalam tabel "riwayat_mutasi" (ganti nama tabel)
        $this->db->insert('sejarah_perubahan', $data); // Ganti nama tabel
    }

    public function tambah_riwayat_resign($karyawan, $sk, $tmt)
    {
        $pegawai = $this->Karyawan->detailKaryawan($karyawan);

        if (!$pegawai) {
            return false; // Tampilkan pesan kesalahan jika ID pegawai tidak valid
        }

        // Data untuk diinsert ke dalam tabel 'riwayat_promosi'
        $data = array(
            'id_pegawai' => $karyawan,
            'jenis_perubahan' => '7', // Mengambil nama operator dari session
            'tgl_sejarah' => date("Y-m-d"),
            'sk' => $sk, // Mengambil tanggal hari ini
            'tmt' => $tmt, // Status karyawan yang baru
            'jam' => date("H:i:s"),
            'from' => 'Pegawai',
            'to' => 'Resign',
            'operator' => $this->session->userdata('id_pegawai')
        );
        // Masukkan data mutasi ke dalam tabel "riwayat_mutasi" (ganti nama tabel)
        $this->db->insert('sejarah_perubahan', $data); // Ganti nama tabel
    }

    public function tambah_riwayat_demosi($karyawan, $divisi_awal, $divisi_baru, $sk, $tmt)
    {
        $pegawai = $this->Karyawan->detailKaryawan($karyawan);

        if (!$pegawai) {
            return false; // Tampilkan pesan kesalahan jika ID pegawai tidak valid
        }

        // Data untuk diinsert ke dalam tabel 'riwayat_promosi'
        $data = array(
            'id_pegawai' => $karyawan,
            'jenis_perubahan' => '8', // Mengambil nama operator dari session
            'tgl_sejarah' => date("Y-m-d"),
            'sk' => $sk, // Mengambil tanggal hari ini
            'tmt' => $tmt, // Status karyawan yang baru
            'from' => $divisi_awal,
            'to' => $divisi_baru,
            'jam' => date("H:i:s"),
            'operator' => $this->session->userdata('id_pegawai')
        );
        // Masukkan data mutasi ke dalam tabel "riwayat_mutasi" (ganti nama tabel)
        $this->db->insert('sejarah_perubahan', $data); // Ganti nama tabel
    }
}